/*
 * XFTA Version 2.0.1
 * xftar.cpp
 *
 * This file is part of the XFTA project.
 * Copyright (c) 2014-2020 AltaRica Association - All Rights Reserved.
 * Unauthorized copying of this file, via any medium, is strictly prohibited.
 * The content of this file is proprietary and confidential.
 * This file has been written by Antoine B. RAUZY.
 */

/*
 * Table of Contents
 * -----------------
 * 1) Include Files
 * 2) Main
 */

/*
 * 1) Include Files
 * ----------------
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "xfta-api.h"

/*
 * 2) Main
 * -------
 */

typedef int (*XFTACommand)(char*);

/*
*/
void XFTA_PrintVersion()
{
	printf("XFTA: an Open-PSA fault tree assessment engine\n"
		"version 2.0.1\n"
		"Copyrights (c) AltaRica Association 2020\n");
	fflush(stdout);
}

/*
*/
void XFTA_PrintHelp()
{
	printf("xftar [options] [filename]\n"
		"options:\n"
		"--help, -h: this help."
		"--version, -v: to get the version of XFTA."
		);
	fflush(stdout);
}

/*
*/
int main(int argc, char** argv)
{
	XFTACommand evalScript = nullptr;
	int error = 0;

	#ifdef __WINDOWS__
		HINSTANCE hDLL;
		hDLL = LoadLibrary("xfta.dll");
		if (hDLL==nullptr) {
			fprintf(stderr, "No xfta DLL\n");
			fflush(stderr);
			exit(1);
			}
		evalScript = (XFTACommand) GetProcAddress(hDLL, "XFTA_EvalScript");
	#endif

	#ifdef __UNIX__
		evalScript = XFTA_EvalScript;
	#endif

	if (evalScript==nullptr) {
		fprintf(stderr, "Missing function XFTA_EvalScript\n");
		fflush(stderr);
		exit(1);
		}

	for (int i=1; i<argc && error==0; i++)
		if (strcmp(argv[i],"--help")==0 || strcmp(argv[i],"-h")==0)
			XFTA_PrintHelp();
		else if (strcmp(argv[i],"--version")==0 || strcmp(argv[i],"-v")==0)
			XFTA_PrintVersion();
		else
			error = evalScript(argv[i]);

	#ifdef __WINDOWS__
		FreeLibrary(hDLL);
	#endif

	printf("bye\n");
	fflush(stdout);
	return error;
}



